@@ -11,7 +11,7 @@ use Encode::Locale qw(decode_argv);
 
 
 use 5.008_005;
-our $VERSION = '5.18.0.1.25';
+our $VERSION = '5.18.0.1.26';
 
 our @EXPORT = qw(print_pod print_pods);
 
@@ -124,9 +124,8 @@ POD2::RU - Perl Документация по-русски
                                                                                           
 =head1 DESCRIPTION
 
-POD2::RU is
-
-Этот модуль содержит перевод Perl-документации на русский. Домашняя страница проекта ─ L<https://github.com/mishin/perldoc-ru>. 
+Модуль POD2::RU содержит перевод Perl-документации на русский. 
+Домашняя страница проекта ─ L<https://github.com/mishin/POD-to-RU>. 
 
 После установки пакета, вы можете использовать следующую команду, чтобы получить документацию:
 
